--beginvalidatingquery 
IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA = 'dbo' AND TABLE_NAME = 'SchemaVersion') 
    BEGIN 
    declare @major int = 10, @minor int = 0, @patch int = 31    
    IF EXISTS (SELECT 1 FROM dbo.SchemaVersion WHERE Major = @major AND Minor = @minor AND Patch = @patch) 
        select 0,'Already correct database version' 
    ELSE 
        select 1, 'Upgrading database' 
    END 
ELSE 
    select -1, 'Not an EPiServer Commerce database' 
--endvalidatingquery 
PRINT N'Altering [dbo].[ecfVersionCatalog_Save]...';


GO
ALTER PROCEDURE [dbo].[ecfVersionCatalog_Save]
	@VersionCatalogs dbo.[udttVersionCatalog] readonly,
	@PublishAction bit
AS
BEGIN
	MERGE dbo.ecfVersionCatalog AS TARGET
	USING @VersionCatalogs AS SOURCE
	ON (TARGET.WorkId = SOURCE.WorkId)
	WHEN MATCHED THEN 
		UPDATE SET DefaultCurrency = SOURCE.DefaultCurrency,
				   WeightBase = SOURCE.WeightBase,
				   LengthBase = SOURCE.LengthBase,
				   DefaultLanguage = SOURCE.DefaultLanguage,
				   Languages = SOURCE.Languages,
				   IsPrimary = SOURCE.IsPrimary,
				   [Owner] = SOURCE.[Owner]
	WHEN NOT MATCHED THEN
		INSERT (WorkId, DefaultCurrency, WeightBase, LengthBase, DefaultLanguage, Languages, IsPrimary, [Owner])
		VALUES (SOURCE.WorkId, SOURCE.DefaultCurrency, SOURCE.WeightBase, SOURCE.LengthBase, SOURCE.DefaultLanguage, SOURCE.Languages, SOURCE.IsPrimary, SOURCE.[Owner])
	;

	IF @PublishAction = 1
	BEGIN
		-- Gets versions which had updated on DefaultLanguage or Languages, that will be used to update versions related to them when publishing a catalog.
		DECLARE @WorkIds TABLE (WorkId INT, DefaultLanguage NVARCHAR(20), Languages NVARCHAR(4000))
		INSERT INTO @WorkIds(WorkId, DefaultLanguage, Languages)
		SELECT v.WorkId, v.DefaultLanguage, v.Languages
		FROM @VersionCatalogs v
		INNER JOIN ecfVersion n on v.WorkId = n.WorkId
		INNER JOIN Catalog c on n.CatalogId = c.CatalogId
		WHERE v.DefaultLanguage <> c.DefaultLanguage

		DECLARE @NumberVersions INT, @CatalogId INT, @MasterLanguageName NVARCHAR(20), @Languages NVARCHAR(4000)
		SELECT @NumberVersions = COUNT(*) FROM @WorkIds

		IF @NumberVersions = 1 -- This is the most regular case, so we can do in different way without cursor so that can gain performance
		BEGIN
			DECLARE @WorkId INT
			
			SELECT TOP 1 @WorkId = WorkId, @MasterLanguageName = DefaultLanguage, @Languages = Languages FROM @WorkIds
			SELECT @CatalogId = ObjectId FROM ecfVersion WHERE WorkId = @WorkId

			UPDATE d SET 
				d.DefaultLanguage = @MasterLanguageName
			FROM ecfVersionCatalog d
			INNER JOIN ecfVersion v ON d.WorkId = v.WorkId
			WHERE v.ObjectTypeId = 2 AND v.ObjectId = @CatalogId AND d.DefaultLanguage <> @MasterLanguageName

			UPDATE ecfVersion SET 
				MasterLanguageName = @MasterLanguageName
			WHERE CatalogId = @CatalogId AND MasterLanguageName <> @MasterLanguageName
		END
		ELSE IF @NumberVersions > 1
		BEGIN
			DECLARE @Catalogs udttObjectWorkId

			INSERT INTO @Catalogs(ObjectId, ObjectTypeId, LanguageName, WorkId)
			SELECT c.ObjectId, c.ObjectTypeId, w.DefaultLanguage, c.WorkId
			FROM ecfVersion c 
			INNER JOIN @WorkIds w ON c.WorkId = w.WorkId
			WHERE c.ObjectTypeId = 2
			-- Note that @Catalogs.LanguageName is @WorkIds.DefaultLanguage
			
			DECLARE @ObjectIdsTemp TABLE(ObjectId INT)
			DECLARE catalogCursor CURSOR FOR SELECT DISTINCT ObjectId FROM @Catalogs
		
			OPEN catalogCursor  
			FETCH NEXT FROM catalogCursor INTO @CatalogId
		
			WHILE @@FETCH_STATUS = 0  
			BEGIN
				SELECT @MasterLanguageName = v.DefaultLanguage
				FROM @VersionCatalogs v
				INNER JOIN @Catalogs c ON c.WorkId = v.WorkId
				WHERE c.ObjectId = @CatalogId
						
				-- when publishing a Catalog, we need to update all drafts to have the same DefaultLanguage as the published one.
				UPDATE d SET 
					d.DefaultLanguage = @MasterLanguageName
				FROM ecfVersionCatalog d
				INNER JOIN ecfVersion v ON d.WorkId = v.WorkId
				WHERE v.ObjectTypeId = 2 AND v.ObjectId = @CatalogId AND d.DefaultLanguage <> @MasterLanguageName
			
				-- and also update MasterLanguageName of contents that's related to Catalog
				-- catalogs
				UPDATE ecfVersion SET 
					MasterLanguageName = @MasterLanguageName
				WHERE CatalogId = @CatalogId AND MasterLanguageName <> @MasterLanguageName
				
				FETCH NEXT FROM catalogCursor INTO @CatalogId
			END
		
			CLOSE catalogCursor  
			DEALLOCATE catalogCursor;  
		END
	END
END
GO
PRINT N'Refreshing [dbo].[ecfVersion_SyncCatalogData]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ecfVersion_SyncCatalogData]';


GO
PRINT N'Refreshing [dbo].[ecfVersion_Update]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ecfVersion_Update]';


GO
 
GO 


 
--beginUpdatingDatabaseVersion 
 
INSERT INTO dbo.SchemaVersion(Major, Minor, Patch, InstallDate) VALUES(10, 0, 31, GETUTCDATE()) 
 
GO 

--endUpdatingDatabaseVersion 
